/* lightlab, Copyright (c) 2002 Jamie Zawinski <jwz@jwz.org>
 *
 * Permission to use, copy, modify, distribute, and sell this software and its
 * documentation for any purpose is hereby granted without fee, provided that
 * the above copyright notice appear in all copies and that both that
 * copyright notice and this permission notice appear in supporting
 * documentation.  No representations are made about the suitability of this
 * software for any purpose.  It is provided "as is" without express or 
 * implied warranty.
 */

#ifndef __SPHERE_H__
#define __SPHERE_H__

extern void unit_cube (int wire_p);
extern void unit_sphere (int stacks, int slices, int wire_p);
extern void unit_tube (int faces, int smooth, int wire);
extern void unit_cone (int faces, int smooth, int wire);

#endif /* __SPHERE_H__ */
